@@ -219,10 +219,6 @@ class CoreApiConnector(CoreApiClient):
     ) -> resources.certificate_managers.CertificateManagers:
         return resources.certificate_managers.CertificateManagers(self)
 
-    @cached_property
-    def tombstones(self) -> resources.tombstones.Tombstones:
-        return resources.tombstones.Tombstones(self)
-
     @cached_property
     def clusters(self) -> resources.clusters.Clusters:
         return resources.clusters.Clusters(self)
@@ -323,6 +319,10 @@ class CoreApiConnector(CoreApiClient):
     def redis_instances(self) -> resources.redis_instances.RedisInstances:
         return resources.redis_instances.RedisInstances(self)
 
+    @cached_property
+    def n8n_instances(self) -> resources.n8n_instances.N8nInstances:
+        return resources.n8n_instances.N8nInstances(self)
+
     @cached_property
     def task_collections(self) -> resources.task_collections.TaskCollections:
         return resources.task_collections.TaskCollections(self)
